@@ -1,8 +1,7 @@
 #include <gtk/gtk.h>
 #include <clutter/clutter.h>
 
-#include <clutter-gtk/gtk-clutter-embed.h>
-#include <clutter-gtk/gtk-clutter-util.h>
+#include <clutter-gtk/clutter-gtk.h>
 
 typedef struct {
 
@@ -21,7 +20,7 @@ on_gtk_entry_changed (GtkEditable *editable, EventApp *app)
 {
   const gchar *text = gtk_entry_get_text (GTK_ENTRY (editable));
 
-  clutter_entry_set_text (CLUTTER_ENTRY (app->clutter_entry), text);
+  clutter_text_set_text (CLUTTER_TEXT (app->clutter_entry), text);
 }
 
 static void
@@ -75,11 +74,11 @@ on_stage_capture (ClutterActor *actor,
 {
   if (event->type == CLUTTER_BUTTON_RELEASE)
     {
-      gint x, y;
+      gfloat x, y;
 
       clutter_event_get_coords (event, &x, &y);
 
-      g_print ("Event captured at (%d, %d)\n", x, y);
+      g_print ("Event captured at (%.2f, %.2f)\n", x, y);
     }
 
   return FALSE;
@@ -103,7 +102,7 @@ main (gint argc, gchar **argv)
   GtkWidget     *widget, *vbox, *hbox, *button, *label, *box;
   ClutterActor  *actor;
   GdkPixbuf     *pixbuf = NULL;
-  guint          width, height;
+  gfloat         width, height;
   ClutterColor   stage_color = {255, 255, 255, 255};
   ClutterColor   text_color = {0, 0, 0, 255};
 
@@ -161,7 +160,7 @@ main (gint argc, gchar **argv)
                     NULL);
 
   /* Setup the clutter entry */
-  actor = clutter_entry_new_full ("Sans 10", "", &text_color);
+  actor = clutter_text_new_full ("Sans 10", "", &text_color);
   app->clutter_entry = actor;
   clutter_group_add (CLUTTER_GROUP (app->stage), actor);
   clutter_actor_set_position (actor, 0, 0);
